@@ -8,7 +8,6 @@
 #' @param direction Which direction is better? 1 = higher, -1 = lower
 #'
 #' @importFrom stats sd
-#' @importFrom rlang .data
 #'
 #' @return A vector with RCIs
 #'
@@ -16,14 +15,13 @@
 .calc_rci_gln <- function(data, m_pre, sd_pre, reliability, direction = 1) {
   se_prediction <- .calc_se_prediction(sd_pre = sd_pre, reliability = reliability)
 
-
   # Calculate RCI
   rci_data <- data %>%
     mutate(
-      pre_adj = reliability * (.data$pre - m_pre),
-      post_adj = .data$post - m_pre,
-      change_adj = .data$post_adj - .data$pre_adj,
-      rci = .data$change_adj / se_prediction
+      pre_adj = reliability * (pre - m_pre),
+      post_adj = post - m_pre,
+      change_adj = post_adj - pre_adj,
+      rci = change_adj / se_prediction
     )
 
 
