@@ -20,10 +20,10 @@
   # Calculate RCI
   rci_data <- data %>%
     mutate(
-      pre_adj = reliability * (.data$pre - m_pre),
-      post_adj = .data$post - m_post,
-      change_adj = .data$post_adj - .data$pre_adj,
-      rci = .data$change_adj / se_prediction
+      pre_adj = reliability * (pre - m_pre),
+      post_adj = post - m_post,
+      change_adj = post_adj - pre_adj,
+      rci = change_adj / se_prediction
     )
 
 
